@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
-# blaze-add, add a blog post or a page to the BlazeBlogger repository
-# Copyright (C) 2008, 2009 Jaromir Hradilek
+# blaze-add - adds a blog post or a page to the BlazeBlogger repository
+# Copyright (C) 2008-2011 Jaromir Hradilek
 
 # This program is  free software:  you can redistribute it and/or modify it
 # under  the terms  of the  GNU General Public License  as published by the
@@ -26,42 +26,49 @@ use Getopt::Long;
 
 # General script information:
 use constant NAME    => basename($0, '.pl');        # Script name.
-use constant VERSION => '1.0.0';                    # Script version.
+use constant VERSION => '1.2.0';                    # Script version.
 
 # General script settings:
 our $blogdir  = '.';                                # Repository location.
+our $editor   = '';                                 # Editor to use.
 our $process  = 1;                                  # Use processor?
 our $verbose  = 1;                                  # Verbosity level.
 
 # Global variables:
 our $chosen   = 1;                                  # Available ID guess.
-our $reserved = undef;                              # Reserved IDs list.
+our $reserved = undef;                              # Reserved ID list.
 our $conf     = {};                                 # Configuration.
 
-# Command-line options:
+# Command line options:
 my  $type     = 'post';                             # Type: post or page.
 my  $added    = '';                                 # List of added IDs.
-my  $data     = {};                                 # Post/page metadata.
+my  $data     = {};                                 # Post/page meta data.
 
 # Set up the __WARN__ signal handler:
 $SIG{__WARN__} = sub {
   print STDERR NAME . ": " . (shift);
 };
 
-# Display given message and terminate the script:
+# Display an error message, and terminate the script:
 sub exit_with_error {
-  my $message      = shift || 'An unspecified error has occurred.';
+  my $message      = shift || 'An error has occurred.';
   my $return_value = shift || 1;
 
+  # Display the error message:
   print STDERR NAME . ": $message\n";
+
+  # Terminate the script:
   exit $return_value;
 }
 
-# Display given warning message:
+# Display a warning message:
 sub display_warning {
-  my $message = shift || 'An unspecified warning was requested.';
+  my $message = shift || 'A warning was requested.';
 
+  # Display the warning message:
   print STDERR "$message\n";
+
+  # Return success:
   return 1;
 }
 
@@ -69,24 +76,27 @@ sub display_warning {
 sub display_help {
   my $NAME = NAME;
 
-  # Print the message to the STDOUT:
+  # Display the usage:
   print << "END_HELP";
-Usage: $NAME [-pqCPV] [-b directory] [-a author] [-d date] [-t title]
-                 [-T tags] [-u url] [file...]
-       $NAME -h | -v
+Usage: $NAME [-pqCPV] [-b DIRECTORY] [-E EDITOR] [-a AUTHOR] [-d DATE]
+                 [-t TITLE] [-k KEYWORDS] [-T TAGS] [-u URL] [FILE...]
+       $NAME -h|-v
 
-  -b, --blogdir directory     specify the directory where the BlazeBlogger
+  -b, --blogdir DIRECTORY     specify a directory in which the BlazeBlogger
                               repository is placed
-  -t, --title title           use given title
-  -a, --author author         use given author
-  -d, --date date             use given date; has to be in YYYY-MM-DD form
-  -T, --tags tags             tag the blog post; pages ignore these
-  -u, --url url               use given url; based on the title by default
-  -p, --page                  add page instead of blog post
-  -P, --post                  add blog post; the default option
-  -C, --no-processor          disable the use of external processor
-  -q, --quiet                 avoid displaying unnecessary messages
-  -V, --verbose               display all messages; the default option
+  -E, --editor EDITOR         specify an external text editor
+  -t, --title TITLE           specify a title
+  -a, --author AUTHOR         specify an author
+  -d, --date DATE             specify a date of publishing
+  -k, --keywords KEYWORDS     specify a comma-separated list of keywords
+  -T, --tags TAGS             specify a comma-separated list of tags
+  -u, --url URL               specify a URL
+  -p, --page                  add a page or pages
+  -P, --post                  add a blog post or blog posts
+  -C, --no-processor          disable processing the blog post or page with
+                              an external application
+  -q, --quiet                 do not display unnecessary messages
+  -V, --verbose               display all messages
   -h, --help                  display this help and exit
   -v, --version               display version information and exit
 END_HELP
@@ -99,11 +109,11 @@ END_HELP
 sub display_version {
   my ($NAME, $VERSION) = (NAME, VERSION);
 
-  # Print the message to the STDOUT:
+  # Display the version:
   print << "END_VERSION";
 $NAME $VERSION
 
-Copyright (C) 2008, 2009 Jaromir Hradilek
+Copyright (C) 2008-2011 Jaromir Hradilek
 This program is free software; see the source for copying conditions. It is
 distributed in the hope  that it will be useful,  but WITHOUT ANY WARRANTY;
 without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PAR-
@@ -114,7 +124,7 @@ END_VERSION
   return 1;
 }
 
-# Translate given date to YYYY-MM-DD string:
+# Translate a date to the YYYY-MM-DD form:
 sub date_to_string {
   my @date = localtime(shift);
   return sprintf("%d-%02d-%02d", ($date[5] + 1900), ++$date[4], $date[3]);
@@ -133,13 +143,13 @@ sub read_ini {
 
   # Process each line:
   while (my $line = <INI>) {
-    # Parse line:
+    # Parse the line:
     if ($line =~ /^\s*\[([^\]]+)\]\s*$/) {
       # Change the section:
       $section = $1;
     }
     elsif ($line =~ /^\s*(\S+)\s*=\s*(\S.*)$/) {
-      # Add option to the hash:
+      # Add the option to the hash:
       $hash->{$section}->{$1} = $2;
     }
   }
@@ -161,12 +171,12 @@ sub write_ini {
 
   # Process each section:
   foreach my $section (sort(keys(%$hash))) {
-    # Write the section header:
+    # Write the section header to the file::
     print INI "[$section]\n";
 
     # Process each option in the section:
     foreach my $option (sort(keys(%{$hash->{$section}}))) {
-      # Write the option and its value:
+      # Write the option and its value to the file:
       print INI "  $option = $hash->{$section}->{$option}\n";
     }
   }
@@ -178,7 +188,7 @@ sub write_ini {
   return 1;
 }
 
-# Read the configuration file:
+# Read the content of the configuration file:
 sub read_conf {
   # Prepare the file name:
   my $file = catfile($blogdir, '.blaze', 'config');
@@ -190,14 +200,14 @@ sub read_conf {
   }
   else {
     # Report failure:
-    display_warning("Unable to read configuration.");
+    display_warning("Unable to read the configuration.");
 
-    # Return empty configuration:
+    # Return an empty configuration:
     return {};
   }
 }
 
-# Make proper URL from given string, stripping all forbidden characters:
+# Make proper URL from the string while stripping all forbidden characters:
 sub make_url {
   my $url = shift || return '';
 
@@ -214,56 +224,35 @@ sub make_url {
   return $url;
 }
 
-# Fix the erroneous or missing header data:
-sub fix_header {
+# Look for erroneous or missing header data:
+sub check_header {
   my $data = shift || die 'Missing argument';
   my $id   = shift || die 'Missing argument';
   my $type = shift || die 'Missing argument';
 
   # Check whether the title is specified:
-  if ($data->{header}->{title}) {
-    # Strip trailing spaces:
-    $data->{header}->{title} =~ s/\s+$//;
-  }
-  else {
-    # Assign the default value:
-    my $title = $data->{header}->{title} = 'Untitled';
-
+  unless ($data->{header}->{title}) {
     # Display the appropriate warning:
-    display_warning("Missing title in the $type with ID $id. " .
-                    "Using `$title' instead.");
+    display_warning("Missing title in the $type with ID $id.");
   }
 
   # Check whether the author is specified:
   unless ($data->{header}->{author}) {
-    # Assign the default value:
-    my $author = $data->{header}->{author}
-               = $conf->{user}->{name} || 'admin';
-
-    # Report missing author:
-    display_warning("Missing author in the $type with ID $id. " .
-                    "Using `$author' instead.");
+    # Report the missing author:
+    display_warning("Missing author in the $type with ID $id.");
   }
 
   # Check whether the date is specified:
   if (my $date = $data->{header}->{date}) {
     # Check whether the format is valid:
     unless ($date =~ /\d{4}-[01]\d-[0-3]\d/) {
-      # Use current date instead:
-      $date = $data->{header}->{date} = date_to_string(time);
-
-      # Report invalid date:
-      display_warning("Invalid date in the $type with ID $id. " .
-                      "Using `$date' instead.");
+      # Report the invalid date:
+      display_warning("Invalid date in the $type with ID $id.");
     }
   }
   else {
-    # Use current date instead:
-    my $date = $data->{header}->{date} = date_to_string(time);
-
-    # Report missing date:
-    display_warning("Missing date in the $type with ID $id. " .
-                    "Using `$date' instead.");
+    # Report the missing date:
+    display_warning("Missing date in the $type with ID $id.");
   }
 
   # Check whether the tags are specified:
@@ -271,27 +260,24 @@ sub fix_header {
     # Make all tags lower case:
     $tags = lc($tags);
 
-    # Strip superfluous spaces:
+    # Strip superfluous characters:
     $tags =~ s/\s{2,}/ /g;
     $tags =~ s/\s+$//;
-
-    # Strip trailing commas:
     $tags =~ s/^,+|,+$//g;
 
     # Remove duplicates:
     my %temp = map { $_, 1 } split(/,+\s*/, $tags);
-    $data->{header}->{tags} = join(', ', sort(keys %temp));
 
-    # Make sure non of the tags will have empty URL:
+    # Make sure none of the tags will have an empty URL:
     foreach my $tag (keys %temp) {
-      # Derive URL from tag name:
+      # Derive the URL from the tag name:
       my $tag_url = make_url($tag);
 
       # Make sure the result is not empty:
       unless ($tag_url) {
-        # Report missing tag URL:
-        display_warning("Unable to derive URL from tag `$tag'. " .
-                        "You might want to use ASCII only.");
+        # Report the missing tag URL:
+        display_warning("Unable to derive the URL from the tag `$tag'. " .
+                        "Please use ASCII characters only.");
       }
     }
   }
@@ -300,26 +286,23 @@ sub fix_header {
   if (my $url = $data->{header}->{url}) {
     # Check whether it contains forbidden characters:
     if ($url =~ /[^\w\-]/) {
-      # Strip forbidden characters:
-      $data->{header}->{url} = $url = make_url($url);
-
-      # Report invalid URL:
-      display_warning("Invalid URL in the $type with ID $id. " .
-                      ($url ? "Stripping to `$url'."
-                            : "It will be derived from title."));
+      # Report the invalid URL:
+      display_warning("Invalid URL in the $type with ID $id." .
+                      ($url ? "" : " It will be derived from the title."));
     }
   }
 
-  # Make sure the URL can be derived from title if necessary:
+  # Make sure the URL can be derived from the title if necessary:
   unless ($data->{header}->{url}) {
-    # Derive URL from the post/page title:
-    my $url = make_url(lc($data->{header}->{title}));
+    # Derive the URL from the post or page title:
+    my $title = $data->{header}->{title} || '';
+    my $url   = make_url(lc($title));
 
     # Check whether the URL is not empty:
     unless ($url) {
-      # Report missing URL:
-      display_warning("Unable to derive URL in the $type with ID $id. " .
-                      "You might want to specify it yourself.");
+      # Report the missing URL:
+      display_warning("Unable to derive the URL in the $type with ID $id. " .
+                      "Please specify it yourself.");
     }
   }
 
@@ -327,7 +310,7 @@ sub fix_header {
   return 1;
 }
 
-# Create a record from the single file:
+# Create a record from a single file:
 sub save_record {
   my $file = shift || die 'Missing argument';
   my $id   = shift || die 'Missing argument';
@@ -357,7 +340,7 @@ sub save_record {
 
   # Check whether the processor is enabled:
   if ($process) {
-    # Substitute the placeholders with actual file names:
+    # Substitute placeholders with actual file names:
     $processor  =~ s/%in%/$temp_raw/ig;
     $processor  =~ s/%out%/$temp_body/ig;
   }
@@ -367,17 +350,17 @@ sub save_record {
 
   # Parse the file header:
   while ($line = <FIN>) {
-    # Header ends with the first line not beginning with `#':
+    # The header ends with the first line not beginning with "#":
     last unless $line =~ /^#/;
 
-    # Collect the data for the record header:
-    if ($line =~ /(title|author|date|tags|url):\s*(\S.*)$/) {
+    # Collect data for the record header:
+    if ($line =~ /(title|author|date|keywords|tags|url):\s*(\S.*)$/) {
       $data->{header}->{$1} = $2;
     }
   }
 
-  # Fix erroneous or missing header data:
-  fix_header($data, $id, $type);
+  # Look for erroneous or missing header data:
+  check_header($data, $id, $type);
 
   # Write the record header to the temporary file:
   write_ini($temp_head, $data) or return 0;
@@ -408,10 +391,10 @@ sub save_record {
     # Make sure the raw record directory exists:
     unless (-d $raw_dir) {
       # Create the target directory tree:
-      eval { mkpath($raw_dir, { verbose => 0 }); };
+      eval { mkpath($raw_dir, 0); };
 
       # Make sure the directory creation was successful:
-      exit_with_error("Creating directory tree: $@", 13) if $@;
+      exit_with_error("Creating the directory tree: $@", 13) if $@;
     }
 
     # Create the raw record file:
@@ -421,10 +404,10 @@ sub save_record {
   # Make sure the record body and header directories exist:
   unless (-d $head_dir && -d $body_dir) {
     # Create the target directory tree:
-    eval { mkpath($head_dir, $body_dir, { verbose => 0 }); };
+    eval { mkpath([$head_dir, $body_dir], 0); };
 
     # Make sure the directory creation was successful:
-    exit_with_error("Creating directory tree: $@", 13) if $@;
+    exit_with_error("Creating the directory tree: $@", 13) if $@;
   }
 
   # Create the record body and header files:
@@ -435,14 +418,14 @@ sub save_record {
   return 1;
 }
 
-# Collect reserved posts/pages IDs:
+# Collect reserved post or page IDs:
 sub collect_ids {
   my $type = shift || 'post';
 
-  # Prepare the posts/pages directory name:
+  # Prepare the post or page directory name:
   my $head = catdir($blogdir, '.blaze', "${type}s", 'head');
 
-  # Open the headers directory:
+  # Open the header directory:
   opendir(HEADS, $head) or return 0;
 
   # Build a list of used IDs:
@@ -462,11 +445,11 @@ sub choose_id {
   # Get the list of reserved IDs unless already done:
   @$reserved = collect_ids($type) unless defined $reserved;
 
-  # Iterate through used IDs:
+  # Iterate through the used IDs:
   while (my $used = shift(@$reserved)) {
     # Check whether the candidate ID is really free:
     if ($chosen == $used) {
-      # Try next ID:
+      # Try the next ID:
       $chosen++;
     }
     else {
@@ -478,7 +461,7 @@ sub choose_id {
     }
   }
 
-  # Return the result and increase the next candidate:
+  # Return the result, and increase the next candidate number:
   return $chosen++;
 }
 
@@ -506,40 +489,69 @@ sub add_files {
   return @list;
 }
 
-# Add new record to the repository:
+# Add a new record to the repository:
 sub add_new {
   my $type = shift || 'post';
   my $data = shift || {};
 
   # Decide which editor to use:
-  my $edit = $conf->{core}->{editor} || $ENV{EDITOR} || 'vi';
+  my $edit = $editor || $conf->{core}->{editor} || $ENV{EDITOR} || 'vi';
 
   # Prepare the data for the temporary file header:
-  my $title  = $data->{header}->{title} || '';
-  my $author = $data->{header}->{author}|| $conf->{user}->{name} || 'admin';
-  my $date   = $data->{header}->{date}  || date_to_string(time);
-  my $tags   = $data->{header}->{tags}  || '';
-  my $url    = $data->{header}->{url}   || '';
+  my $title    = $data->{header}->{title}    || '';
+  my $author   = $data->{header}->{author}   || $conf->{user}->{nickname}
+                                             || $conf->{user}->{name}
+                                             || 'admin';
+  my $date     = $data->{header}->{date}     || date_to_string(time);
+  my $keywords = $data->{header}->{keywords} || '';
+  my $tags     = $data->{header}->{tags}     || '';
+  my $url      = $data->{header}->{url}      || '';
+
+  # Declare other necessary variables:
+  my $head;
 
   # Prepare the temporary file header:
-  my $head = << "END_HEAD";
-# This and following lines beginning with  `#' are the $type header.  Please
-# take your time and replace these options with desired values. Just remem-
-# ber that the date has to be in an YYYY-MM-DD form, tags are a comma sepa-
-# rated list of categories the post (pages ignore these) belong to, and the
-# url, if provided, should consist of alphanumeric characters,  hyphens and
-# underscores only. Specifying your own url  is especially recommended when
-# you use non-ASCII characters in your $type title.
+  if ($type eq 'post') {
+    # Use the variant for a blog post:
+    $head = << "END_POST_HEADER";
+# This and the following lines beginning with '#' are the blog post header.
+# Please take your time and replace these options with desired values. Just
+# remember that the date has to be in the YYYY-MM-DD form, tags are a comma
+# separated list of categories the post (pages ignore these) belong to, and
+# the url,  if provided, should consist of alphanumeric characters, hyphens
+# and underscores only.  Specifying your own url  is especially recommended
+# in case you use non-ASCII characters in your blog post title.
 #
-#   title:  $title
-#   author: $author
-#   date:   $date
-#   tags:   $tags
-#   url:    $url
+#   title:    $title
+#   author:   $author
+#   date:     $date
+#   keywords: $keywords
+#   tags:     $tags
+#   url:      $url
 #
-# The header ends here. The rest is the content of your $type.
+# The header ends here. The rest is the content of your blog post.
 
-END_HEAD
+END_POST_HEADER
+  }
+  else {
+    # Use the variant for a page:
+    $head = << "END_PAGE_HEADER";
+# This and the following lines beginning with '#' are the page header. Ple-
+# ase take your time and replace these  options with  desired  values. Just
+# remember that the date has to be in the YYYY-MM-DD form, and the  url, if
+# provided, should  consist of alphanumeric characters,  hyphens and under-
+# scores only. Specifying your own url  is especially  recommended  in case
+# you use non-ASCII characters in your page title.
+#
+#   title:    $title
+#   date:     $date
+#   keywords: $keywords
+#   url:      $url
+#
+# The header ends here. The rest is the content of your page.
+
+END_PAGE_HEADER
+  }
 
   # Prepare the temporary file name:
   my $temp = catfile($blogdir, '.blaze', 'temp');
@@ -554,7 +566,7 @@ END_HEAD
   }
   else {
     # Report failure:
-    display_warning("Unable to create temporary file.");
+    display_warning("Unable to create the temporary file.");
 
     # Return failure:
     return 0;
@@ -566,12 +578,12 @@ END_HEAD
     exit_with_error("Unable to run `$edit'.", 1);
   }
 
-  # Opent the file for reading:
+  # Open the file for reading:
   if (open(FILE, "$temp")) {
-    # Set the IO handler to binmode:
+    # Set the input/output handler to "binmode":
     binmode(FILE);
 
-    # Count checksums:
+    # Count the checksums:
     my $before = Digest::MD5->new->add($head)->hexdigest;
     my $after  = Digest::MD5->new->addfile(*FILE)->hexdigest;
 
@@ -581,14 +593,14 @@ END_HEAD
     # Compare the checksums:
     if ($before eq $after) {
       # Report abortion:
-      display_warning("File have not been changed: aborting.");
+      display_warning("The file has not been changed: aborting.");
 
       # Return success:
       exit 0;
     }
   }
 
-  # Add file to the repository:
+  # Add the file to the repository:
   my @list = add_files($type, $data, [ $temp ]);
 
   # Remove the temporary file:
@@ -598,7 +610,7 @@ END_HEAD
   return shift(@list);
 }
 
-# Add given string to the log file
+# Add the event to the log:
 sub add_to_log {
   my $text = shift || 'Something miraculous has just happened!';
 
@@ -608,7 +620,7 @@ sub add_to_log {
   # Open the log file for appending:
   open(LOG, ">>$file") or return 0;
 
-  # Write to the log file:
+  # Write the event to the file:
   print LOG localtime(time) . " - $text\n";
 
   # Close the file:
@@ -618,10 +630,10 @@ sub add_to_log {
   return 1;
 }
 
-# Set up the options parser:
+# Set up the option parser:
 Getopt::Long::Configure('no_auto_abbrev', 'no_ignore_case', 'bundling');
 
-# Process command-line options:
+# Process command line options:
 GetOptions(
   'help|h'         => sub { display_help();    exit 0; },
   'version|v'      => sub { display_version(); exit 0; },
@@ -631,14 +643,17 @@ GetOptions(
   'quiet|q'        => sub { $verbose = 0;      },
   'verbose|V'      => sub { $verbose = 1;      },
   'blogdir|b=s'    => sub { $blogdir = $_[1];  },
-  'title|t=s'      => sub { $data->{header}->{title}  = $_[1]; },
-  'author|a=s'     => sub { $data->{header}->{author} = $_[1]; },
-  'date|d=s'       => sub { $data->{header}->{date}   = $_[1]; },
-  'tags|tag|T=s'   => sub { $data->{header}->{tags}   = $_[1]; },
-  'url|u=s'        => sub { $data->{header}->{url}    = $_[1]; },
+  'editor|E=s'     => sub { $editor  = $_[1];  },
+  'title|t=s'      => sub { $data->{header}->{title}    = $_[1]; },
+  'author|a=s'     => sub { $data->{header}->{author}   = $_[1]; },
+  'date|d=s'       => sub { $data->{header}->{date}     = $_[1]; },
+  'keywords|k=s'   => sub { $data->{header}->{keywords} = $_[1]; },
+  'tags|tag|T=s'   => sub { $data->{header}->{tags}     = $_[1]; },
+  'url|u=s'        => sub { $data->{header}->{url}      = $_[1]; },
 );
 
-# Check the repository is present (however naive this method is):
+# Check whether the repository is present, no matter how naive this method
+# actually is:
 exit_with_error("Not a BlazeBlogger repository! Try `blaze-init' first.",1)
   unless (-d catdir($blogdir, '.blaze'));
 
@@ -656,16 +671,16 @@ else {
   $process = 0;
 }
 
-# Check whether any file is supplied:
+# Check whether a file is supplied:
 if (scalar(@ARGV) == 0) {
-  # Add new record to the repository:
+  # Add a new record to the repository:
   $added   = add_new($type, $data)
-    or exit_with_error("Cannot add $type to the repository.", 13);
+    or exit_with_error("Cannot add the $type to the repository.", 13);
 }
 else {
   # Add given files to the repository:
   my @list = add_files($type, $data, \@ARGV)
-    or exit_with_error("Cannot add ${type}s to the repository.", 13);
+    or exit_with_error("Cannot add the ${type}s to the repository.", 13);
 
   # Prepare the list of successfully added IDs:
   $added   =  join(', ', sort(@list));
@@ -686,115 +701,132 @@ __END__
 
 =head1 NAME
 
-blaze-add - add a blog post or a page to the BlazeBlogger repository
+blaze-add - adds a blog post or a page to the BlazeBlogger repository
 
 =head1 SYNOPSIS
 
-B<blaze-add> [B<-pqCPV>] [B<-b> I<directory>] [B<-a> I<author>] [B<-d>
-I<date>] [B<-t> I<title>] [B<-T> I<tags>] [B<-u> I<url>] [I<file>...]
+B<blaze-add> [B<-pqCPV>] [B<-b> I<directory>] [B<-E> I<editor>]
+[B<-a> I<author>] [B<-d> I<date>] [B<-t> I<title>] [B<-k> I<keywords>]
+[B<-T> I<tags>] [B<-u> I<url>] [I<file>...]
 
-B<blaze-add> B<-h> | B<-v>
+B<blaze-add> B<-h>|B<-v>
 
 =head1 DESCRIPTION
 
-B<blaze-add> adds new blog posts or pages to the BlazeBlogger repository.
-If supplied, it tries to read data from the existing I<file>s, otherwise an
-external editor is opened to let you create a new content.
+B<blaze-add> adds a blog post or a page to the BlazeBlogger repository. If
+a I<file> is supplied, it adds the content of that file, otherwise an
+external text editor is opened for you. Note that there are several special
+forms and placeholders that can be used in the text, and that will be
+replaced with a proper data when the blog is generated.
 
-Note that inside your posts and pages, you can use several special
-placeholders to be replaced by appropriate data later, when the static
-content is being generated; the case is not significant, and supported
-placeholders are as follows:
+=head2 Special Forms
+
+=over
+
+=item B<< <!-- break --> >>
+
+A mark to delimit a blog post synopsis.
+
+=back
+
+=head2 Placeholders
 
 =over
 
 =item B<%root%>
 
-Relative path to the root directory of the blog; to be used inside links.
+A relative path to the root directory of the blog.
 
 =item B<%home%>
 
-Relative path to the website home (index) page; to be used inside links.
+A relative path to the index page of the blog.
 
 =item B<%page[>I<id>B<]%>
 
-Relative path to the page with given I<id>; to be used inside links.
+A relative path to a page with the supplied I<id>.
 
 =item B<%post[>I<id>B<]%>
 
-Relative path to the post with given I<id>; to be used inside links.
+A relative path to a blog post with the supplied I<id>.
 
 =item B<%tag[>I<name>B<]%>
 
-Relative path to the tag with given I<name>; to be used inside links.
+A relative path to a tag with the supplied I<name>.
 
 =back
 
-You can also use a special form, B<< <!-- break --> >>, to mark the end of
-a part to be displayed on index page.
-
 =head1 OPTIONS
 
 =over
 
-=item B<-b>, B<--blogdir> I<directory>
+=item B<-b> I<directory>, B<--blogdir> I<directory>
 
-Specify the I<directory> where the BlazeBlogger repository is placed. The
-default option is the current working directory.
+Allows you to specify a I<directory> in which the BlazeBlogger repository
+is placed. The default option is a current working directory.
 
-=item B<-t>, B<--title> I<title>
+=item B<-E> I<editor>, B<--editor> I<editor>
 
-Specify the post/page I<title>.
+Allows you to specify an external text I<editor>. When supplied, this
+option overrides the relevant configuration option.
 
-=item B<-a>, B<--author> I<author>
+=item B<-t> I<title>, B<--title> I<title>
 
-Specify the post/page I<author>.
+Allows you to specify the I<title> of a blog post or page.
 
-=item B<-d>, B<--date> I<date>
+=item B<-a> I<author>, B<--author> I<author>
 
-Specify the post/page date of publishing; the I<date> has to be in the
-YYYY-MM-DD form.
+Allows you to specify the I<author> of a blog post or page.
 
-=item B<-T>, B<--tags> I<tags>
+=item B<-d> I<date>, B<--date> I<date>
 
-Specify the comma separated list of I<tags> attached to the blog post;
-pages ignore these.
+Allows you to specify the I<date> of publishing of a blog post or page.
 
-=item B<-u>, B<--url> I<url>
+=item B<-k> I<keywords>, B<--keywords> I<keywords>
 
-Specify the post/page I<url> to be used instead of the one based on the
-post/page title. It should consist of alphanumeric characters, hyphens and
-underscores only, and it is especially useful if non-ASCII characters are
-present in the title.
+Allows you to specify a comma-separated list of I<keywords> attached to
+a blog post or page.
+
+=item B<-T> I<tags>, B<--tags> I<tags>
+
+Allows you to supply a comma-separated list of I<tags> attached to a blog
+post.
+
+=item B<-u> I<url>, B<--url> I<url>
+
+Allows you to specify the I<url> of a blog post or page. Allowed characters
+are letters, numbers, hyphens, and underscores.
 
 =item B<-p>, B<--page>, B<--pages>
 
-Add page instead of blog post.
+Tells B<blaze-add> to add a page or pages.
 
 =item B<-P>, B<--post>, B<--posts>
 
-Add blog post; this is the default option.
+Tells B<blaze-add> to add a blog post or blog posts. This is the default
+option.
 
 =item B<-C>, B<--no-processor>
 
-Disable the use of external processor. Unless the C<core.processor> is
-enabled in the configuration, this is the default behaviour.
+Disables processing a blog post or page with an external application. For
+example, if you use Markdown to convert the lightweight markup language to
+the valid HTML output, this will enable you to write this particular post
+in plain HTML directly.
 
 =item B<-q>, B<--quiet>
 
-Avoid displaying messages that are not necessary.
+Disables displaying of unnecessary messages.
 
 =item B<-V>, B<--verbose>
 
-Display all messages. This is the default option.
+Enables displaying of all messages. This is the default option.
 
 =item B<-h>, B<--help>
 
-Display usage information and exit.
+Displays usage information and exits.
 
 =item B<-v>, B<--version>
 
-Display version information and exit.
+Displays version information and exits.
 
 =back
 
@@ -804,49 +836,44 @@ Display version information and exit.
 
 =item B<EDITOR>
 
-Unless the BlazeBlogger specific option I<core.editor> is set, blaze-edit
-tries to use system wide settings to decide which editor to run. If neither
-of these options are supplied, the B<vi> is used instead as a considerably
-reasonable choice.
+Unless the B<core.editor> option is set, BlazeBlogger tries to use
+system-wide settings to decide which editor to use.
 
 =back
 
-=head1 FILES
+=head1 EXAMPLE USAGE
 
-=over
+Write a new blog post in an external text editor:
 
-=item I<.blaze/config>
+  ~]$ blaze-add
 
-BlazeBlogger configuration file.
+Add a new blog post from a file:
 
-=back
+  ~]$ blaze-add new_packages.txt
+  Successfully added the post with ID 10.
+
+Write a new page in an external text editor:
+
+  ~]$ blaze-add -p
+
+Write a new page in B<nano>:
+
+  ~]$ blaze-add -p -E nano
 
 =head1 SEE ALSO
 
-B<blaze-config>(1), B<perl>(1).
+B<blaze-init>(1), B<blaze-config>(1), B<blaze-edit>(1), B<blaze-remove>(1),
+B<blaze-make>(1)
 
 =head1 BUGS
 
-To report bug or even send patch, either add new issue to the project
-bugtracker at <http://code.google.com/p/blazeblogger/issues/>, or visit
-the discussion group at <http://groups.google.com/group/blazeblogger/>. You
-can also contact the author directly via e-mail.
-
-=head1 AUTHOR
-
-Written by Jaromir Hradilek <jhradilek@gmail.com>.
-
-Permission is granted to copy, distribute and/or modify this document under
-the terms of the GNU Free Documentation License, Version 1.3 or any later
-version published by the Free Software Foundation; with no Invariant
-Sections, no Front-Cover Texts, and no Back-Cover Texts.
-
-A copy of the license is included as a file called FDL in the main
-directory of the BlazeBlogger source package.
+To report a bug or to send a patch, please, add a new issue to the bug
+tracker at <http://code.google.com/p/blazeblogger/issues/>, or visit the
+discussion group at <http://groups.google.com/group/blazeblogger/>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2008, 2009 Jaromir Hradilek
+Copyright (C) 2008-2011 Jaromir Hradilek
 
 This program is free software; see the source for copying conditions. It is
 distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
