@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
-# blaze-edit, edit a blog post or a page in the BlazeBlogger repository
-# Copyright (C) 2008, 2009 Jaromir Hradilek
+# blaze-edit - edits a blog post or a page in the BlazeBlogger repository
+# Copyright (C) 2008-2011 Jaromir Hradilek
 
 # This program is  free software:  you can redistribute it and/or modify it
 # under  the terms  of the  GNU General Public License  as published by the
@@ -26,10 +26,11 @@ use Getopt::Long;
 
 # General script information:
 use constant NAME    => basename($0, '.pl');        # Script name.
-use constant VERSION => '1.0.0';                    # Script version.
+use constant VERSION => '1.2.0';                    # Script version.
 
 # General script settings:
 our $blogdir = '.';                                 # Repository location.
+our $editor  = '';                                  # Editor to use.
 our $force   = 0;                                   # Force raw file?
 our $process = 1;                                   # Use processor?
 our $verbose = 1;                                   # Verbosity level.
@@ -45,20 +46,26 @@ $SIG{__WARN__} = sub {
   print STDERR NAME . ": " . (shift);
 };
 
-# Display given message and terminate the script:
+# Display an error message, and terminate the script:
 sub exit_with_error {
-  my $message      = shift || 'An unspecified error has occurred.';
+  my $message      = shift || 'An error has occurred.';
   my $return_value = shift || 1;
 
+  # Display the error message:
   print STDERR NAME . ": $message\n";
+
+  # Terminate the script:
   exit $return_value;
 }
 
-# Display given warning message:
+# Display a warning message:
 sub display_warning {
-  my $message = shift || 'An unspecified warning was requested.';
+  my $message = shift || 'A warning was requested.';
 
+  # Display the warning message:
   print STDERR "$message\n";
+
+  # Return success:
   return 1;
 }
 
@@ -66,19 +73,22 @@ sub display_warning {
 sub display_help {
   my $NAME = NAME;
 
-  # Print the message to the STDOUT:
+  # Display the usage:
   print << "END_HELP";
-Usage: $NAME [-fpqCPV] [-b directory] id
-       $NAME -h | -v
+Usage: $NAME [-fpqCPV] [-b DIRECTORY] [-E EDITOR] ID
+       $NAME -h|-v
 
-  -b, --blogdir directory     specify the directory where the BlazeBlogger
+  -b, --blogdir DIRECTORY     specify a directory in which the BlazeBlogger
                               repository is placed
-  -p, --page                  edit page instead of blog post
-  -P, --post                  edit blog post; the default option
-  -f, --force                 force creating the raw file if not present
-  -C, --no-processor          disable the use of external processor
-  -q, --quiet                 avoid displaying unnecessary messages
-  -V, --verbose               display all messages; the default option
+  -E, --editor EDITOR         specify an external text editor
+  -p, --page                  edit a page
+  -P, --post                  edit a blog post
+  -f, --force                 create an empty source file in case it does
+                              not already exist
+  -C, --no-processor          disable processing the blog post or page with
+                              an external application
+  -q, --quiet                 do not display unnecessary messages
+  -V, --verbose               display all messages
   -h, --help                  display this help and exit
   -v, --version               display version information and exit
 END_HELP
@@ -91,11 +101,11 @@ END_HELP
 sub display_version {
   my ($NAME, $VERSION) = (NAME, VERSION);
 
-  # Print the message to the STDOUT:
+  # Display the version:
   print << "END_VERSION";
 $NAME $VERSION
 
-Copyright (C) 2008, 2009 Jaromir Hradilek
+Copyright (C) 2008-2011 Jaromir Hradilek
 This program is free software; see the source for copying conditions. It is
 distributed in the hope  that it will be useful,  but WITHOUT ANY WARRANTY;
 without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PAR-
@@ -106,7 +116,7 @@ END_VERSION
   return 1;
 }
 
-# Translate given date to YYYY-MM-DD string:
+# Translate a date to the YYYY-MM-DD form:
 sub date_to_string {
   my @date = localtime(shift);
   return sprintf("%d-%02d-%02d", ($date[5] + 1900), ++$date[4], $date[3]);
@@ -125,13 +135,13 @@ sub read_ini {
 
   # Process each line:
   while (my $line = <INI>) {
-    # Parse line:
+    # Parse the line:
     if ($line =~ /^\s*\[([^\]]+)\]\s*$/) {
       # Change the section:
       $section = $1;
     }
     elsif ($line =~ /^\s*(\S+)\s*=\s*(\S.*)$/) {
-      # Add option to the hash:
+      # Add the option to the hash:
       $hash->{$section}->{$1} = $2;
     }
   }
@@ -153,12 +163,12 @@ sub write_ini {
 
   # Process each section:
   foreach my $section (sort(keys(%$hash))) {
-    # Write the section header:
+    # Write the section header to the file:
     print INI "[$section]\n";
 
     # Process each option in the section:
     foreach my $option (sort(keys(%{$hash->{$section}}))) {
-      # Write the option and its value:
+      # Write the option and its value to the file:
       print INI "  $option = $hash->{$section}->{$option}\n";
     }
   }
@@ -170,7 +180,7 @@ sub write_ini {
   return 1;
 }
 
-# Read the configuration file:
+# Read the content of the configuration file:
 sub read_conf {
   # Prepare the file name:
   my $file = catfile($blogdir, '.blaze', 'config');
@@ -182,14 +192,14 @@ sub read_conf {
   }
   else {
     # Report failure:
-    display_warning("Unable to read configuration.");
+    display_warning("Unable to read the configuration.");
 
-    # Return empty configuration:
+    # Return an empty configuration:
     return {};
   }
 }
 
-# Make proper URL from given string, stripping all forbidden characters:
+# Make proper URL from the string while stripping all forbidden characters:
 sub make_url {
   my $url = shift || return '';
 
@@ -206,56 +216,35 @@ sub make_url {
   return $url;
 }
 
-# Fix the erroneous or missing header data:
-sub fix_header {
+# Look for erroneous or missing header data:
+sub check_header {
   my $data = shift || die 'Missing argument';
   my $id   = shift || die 'Missing argument';
   my $type = shift || die 'Missing argument';
 
   # Check whether the title is specified:
-  if ($data->{header}->{title}) {
-    # Strip trailing spaces:
-    $data->{header}->{title} =~ s/\s+$//;
-  }
-  else {
-    # Assign the default value:
-    my $title = $data->{header}->{title} = 'Untitled';
-
+  unless ($data->{header}->{title}) {
     # Display the appropriate warning:
-    display_warning("Missing title in the $type with ID $id. " .
-                    "Using `$title' instead.");
+    display_warning("Missing title in the $type with ID $id.");
   }
 
   # Check whether the author is specified:
   unless ($data->{header}->{author}) {
-    # Assign the default value:
-    my $author = $data->{header}->{author}
-               = $conf->{user}->{name} || 'admin';
-
-    # Report missing author:
-    display_warning("Missing author in the $type with ID $id. " .
-                    "Using `$author' instead.");
+    # Report the missing author:
+    display_warning("Missing author in the $type with ID $id.");
   }
 
   # Check whether the date is specified:
   if (my $date = $data->{header}->{date}) {
     # Check whether the format is valid:
     unless ($date =~ /\d{4}-[01]\d-[0-3]\d/) {
-      # Use current date instead:
-      $date = $data->{header}->{date} = date_to_string(time);
-
-      # Report invalid date:
-      display_warning("Invalid date in the $type with ID $id. " .
-                      "Using `$date' instead.");
+      # Report the invalid date:
+      display_warning("Invalid date in the $type with ID $id.");
     }
   }
   else {
-    # Use current date instead:
-    my $date = $data->{header}->{date} = date_to_string(time);
-
-    # Report missing date:
-    display_warning("Missing date in the $type with ID $id. " .
-                    "Using `$date' instead.");
+    # Report the missing date:
+    display_warning("Missing date in the $type with ID $id.");
   }
 
   # Check whether the tags are specified:
@@ -263,27 +252,24 @@ sub fix_header {
     # Make all tags lower case:
     $tags = lc($tags);
 
-    # Strip superfluous spaces:
+    # Strip superfluous characters:
     $tags =~ s/\s{2,}/ /g;
     $tags =~ s/\s+$//;
-
-    # Strip trailing commas:
     $tags =~ s/^,+|,+$//g;
 
     # Remove duplicates:
     my %temp = map { $_, 1 } split(/,+\s*/, $tags);
-    $data->{header}->{tags} = join(', ', sort(keys %temp));
 
-    # Make sure non of the tags will have empty URL:
+    # Make sure none of the tags will have an empty URL:
     foreach my $tag (keys %temp) {
-      # Derive URL from tag name:
+      # Derive the URL from the tag name:
       my $tag_url = make_url($tag);
 
       # Make sure the result is not empty:
       unless ($tag_url) {
-        # Report missing tag URL:
-        display_warning("Unable to derive URL from tag `$tag'. " .
-                        "You might want to use ASCII only.");
+        # Report the missing tag URL:
+        display_warning("Unable to derive a URL from the tag `$tag'. " .
+                        "Please use ASCII characters only.");
       }
     }
   }
@@ -292,26 +278,23 @@ sub fix_header {
   if (my $url = $data->{header}->{url}) {
     # Check whether it contains forbidden characters:
     if ($url =~ /[^\w\-]/) {
-      # Strip forbidden characters:
-      $data->{header}->{url} = $url = make_url($url);
-
-      # Report invalid URL:
-      display_warning("Invalid URL in the $type with ID $id. " .
-                      ($url ? "Stripping to `$url'."
-                            : "It will be derived from title."));
+      # Report the invalid URL:
+      display_warning("Invalid URL in the $type with ID $id." .
+                      ($url ? "" : " It will be derived from the title."));
     }
   }
 
-  # Make sure the URL can be derived from title if necessary:
+  # Make sure the URL can be derived from the title if necessary:
   unless ($data->{header}->{url}) {
-    # Derive URL from the post/page title:
-    my $url = make_url(lc($data->{header}->{title}));
+    # Derive the URL from the post or page title:
+    my $title = $data->{header}->{title} || '';
+    my $url   = make_url(lc($title));
 
     # Check whether the URL is not empty:
     unless ($url) {
-      # Report missing URL:
-      display_warning("Unable to derive URL in the $type with ID $id. " .
-                      "You might want to specify it yourself.");
+      # Report the missing URL:
+      display_warning("Unable to derive the URL in the $type with ID $id. " .
+                      "Please specify it yourself.");
     }
   }
 
@@ -319,7 +302,7 @@ sub fix_header {
   return 1;
 }
 
-# Create a single file from the record:
+# Create a single file from a record:
 sub read_record {
   my $file = shift || die 'Missing argument';
   my $id   = shift || die 'Missing argument';
@@ -330,9 +313,9 @@ sub read_record {
   my $body = catfile($blogdir, '.blaze', "${type}s", 'body', $id);
   my $raw  = catfile($blogdir, '.blaze', "${type}s", 'raw',  $id);
 
-  # If processor is enabled, make sure the raw file exist:
+  # If the processor is enabled, make sure the raw file exists:
   if ($process && ! -e $raw) {
-    exit_with_error("Raw file does not exist. Use `--force' to create " .
+    exit_with_error("The raw file does not exist. Use `--force' to create " .
                     "a new one, or `--no-processor' to disable the " .
                     "processor.", 1)
       unless $force;
@@ -342,39 +325,68 @@ sub read_record {
   my $data = read_ini($head) or return 0;
 
   # Collect the data for the file header:
-  my $author = $data->{header}->{author} || '';
-  my $title  = $data->{header}->{title}  || '';
-  my $date   = $data->{header}->{date}   || '';
-  my $tags   = $data->{header}->{tags}   || '';
-  my $url    = $data->{header}->{url}    || '';
+  my $author   = $data->{header}->{author}   || '';
+  my $title    = $data->{header}->{title}    || '';
+  my $date     = $data->{header}->{date}     || '';
+  my $keywords = $data->{header}->{keywords} || '';
+  my $tags     = $data->{header}->{tags}     || '';
+  my $url      = $data->{header}->{url}      || '';
+
+  # Declare other necessary variables:
+  my $head;
+
+  # Prepare the temporary file header:
+  if ($type eq 'post') {
+    # Use the variant for a blog post:
+    $head = << "END_POST_HEADER";
+# This and the following lines beginning with '#' are the blog post header.
+# Please take your time and replace these options with desired values. Just
+# remember that the date has to be in the YYYY-MM-DD form, tags are a comma
+# separated list of categories the post (pages ignore these) belong to, and
+# the url,  if provided, should consist of alphanumeric characters, hyphens
+# and underscores only.  Specifying your own url  is especially recommended
+# in case you use non-ASCII characters in your blog post title.
+#
+#   title:    $title
+#   author:   $author
+#   date:     $date
+#   keywords: $keywords
+#   tags:     $tags
+#   url:      $url
+#
+# The header ends here. The rest is the content of your blog post.
+END_POST_HEADER
+  }
+  else {
+    # Use the variant for a page:
+    $head = << "END_PAGE_HEADER";
+# This and the following lines beginning with '#' are the page header. Ple-
+# ase take your time and replace these  options with  desired  values. Just
+# remember that the date has to be in the YYYY-MM-DD form, and the  url, if
+# provided, should  consist of alphanumeric characters,  hyphens and under-
+# scores only. Specifying your own url  is especially  recommended  in case
+# you use non-ASCII characters in your page title.
+#
+#   title:    $title
+#   date:     $date
+#   keywords: $keywords
+#   url:      $url
+#
+# The header ends here. The rest is the content of your page.
+END_PAGE_HEADER
+  }
 
   # Open the file for writing:
   if (open(FOUT, ">$file")) {
     # Write the header:
-    print FOUT << "END_HEADER";
-# This and following lines beginning with  `#' are the $type header.  Please
-# take your time and replace these options with desired values. Just remem-
-# ber that the date has to be in an YYYY-MM-DD form, tags are a comma sepa-
-# rated list of categories the post (pages ignore these) belong to, and the
-# url, if provided, should consist of alphanumeric characters,  hyphens and
-# underscores only. Specifying your own url  is especially recommended when
-# you use non-ASCII characters in your $type title.
-#
-#   title:  $title
-#   author: $author
-#   date:   $date
-#   tags:   $tags
-#   url:    $url
-#
-# The header ends here. The rest is the content of your $type.
-END_HEADER
+    print FOUT $head;
 
     # Skip this part when forced to create empty raw file:
     unless ($process && ! -e $raw && $force) {
       # Open the record for the reading:
       open(FIN, ($process ? $raw : $body)) or return 0;
 
-      # Add content of the record body to the file:
+      # Add the content of the record body to the file:
       while (my $line = <FIN>) {
         print FOUT $line;
       }
@@ -391,7 +403,7 @@ END_HEADER
   }
   else {
     # Report failure:
-    display_warning("Unable to create temporary file.");
+    display_warning("Unable to create the temporary file.");
 
     # Return failure:
     return 0;
@@ -428,7 +440,7 @@ sub save_record {
 
   # Check whether the processor is enabled:
   if ($process) {
-    # Substitute the placeholders with actual file names:
+    # Substitute placeholders with actual file names:
     $processor  =~ s/%in%/$temp_raw/ig;
     $processor  =~ s/%out%/$temp_body/ig;
   }
@@ -438,17 +450,17 @@ sub save_record {
 
   # Parse the file header:
   while ($line = <FIN>) {
-    # Header ends with the first line not beginning with `#':
+    # The header ends with the first line not beginning with "#":
     last unless $line =~ /^#/;
 
-    # Collect the data for the record header:
-    if ($line =~ /(title|author|date|tags|url):\s*(\S.*)$/) {
+    # Collect data for the record header:
+    if ($line =~ /(title|author|date|keywords|tags|url):\s*(\S.*)$/) {
       $data->{header}->{$1} = $2;
     }
   }
 
   # Fix erroneous or missing header data:
-  fix_header($data, $id, $type);
+  check_header($data, $id, $type);
 
   # Write the record header to the temporary file:
   write_ini($temp_head, $data) or return 0;
@@ -479,10 +491,10 @@ sub save_record {
     # Make sure the raw record directory exists:
     unless (-d $raw_dir) {
       # Create the target directory tree:
-      eval { mkpath($raw_dir, { verbose => 0 }); };
+      eval { mkpath($raw_dir, 0); };
 
       # Make sure the directory creation was successful:
-      exit_with_error("Creating directory tree: $@", 13) if $@;
+      exit_with_error("Creating the directory tree: $@", 13) if $@;
     }
 
     # Create the raw record file:
@@ -492,10 +504,10 @@ sub save_record {
   # Make sure the record body and header directories exist:
   unless (-d $head_dir && -d $body_dir) {
     # Create the target directory tree:
-    eval { mkpath($head_dir, $body_dir, { verbose => 0 }); };
+    eval { mkpath([$head_dir, $body_dir], 0); };
 
     # Make sure the directory creation was successful:
-    exit_with_error("Creating directory tree: $@", 13) if $@;
+    exit_with_error("Creating the directory tree: $@", 13) if $@;
   }
 
   # Create the record body and header files:
@@ -506,7 +518,7 @@ sub save_record {
   return 1;
 }
 
-# Edit record in the repository:
+# Edit a record in the repository:
 sub edit_record {
   my $id   = shift || die 'Missing argument';
   my $type = shift || 'post';
@@ -518,12 +530,12 @@ sub edit_record {
   my $temp = catfile($blogdir, '.blaze', 'temp');
 
   # Decide which editor to use:
-  my $edit = $conf->{core}->{editor} || $ENV{EDITOR} || 'vi';
+  my $edit = $editor || $conf->{core}->{editor} || $ENV{EDITOR} || 'vi';
 
   # Create the temporary file:
   unless (read_record($temp, $id, $type)) {
     # Report failure:
-    display_warning("Unable to read record with ID $id.");
+    display_warning("Unable to read the $type with ID $id.");
 
     # Return failure:
     return 0;
@@ -531,10 +543,10 @@ sub edit_record {
 
   # Open the file for reading:
   if (open(FILE, "$temp")) {
-    # Set the IO handler to binmode:
+    # Set the input/output handler to "binmode":
     binmode(FILE);
 
-    # Count checksum:
+    # Count the checksum:
     $before = Digest::MD5->new->addfile(*FILE)->hexdigest;
 
     # Close the file:
@@ -552,10 +564,10 @@ sub edit_record {
 
   # Open the file for reading:
   if (open(FILE, "$temp")) {
-    # Set the IO handler to binmode:
+    # Set the input/output handler to "binmode":
     binmode(FILE);
 
-    # Count checksum:
+    # Count the checksum:
     $after = Digest::MD5->new->addfile(*FILE)->hexdigest;
 
     # Close the file:
@@ -564,7 +576,7 @@ sub edit_record {
     # Compare the checksums:
     if ($before eq $after) {
       # Report abortion:
-      display_warning("File have not been changed: aborting.");
+      display_warning("The file has not been changed: aborting.");
 
       # Return success:
       exit 0;
@@ -574,7 +586,7 @@ sub edit_record {
   # Save the record:
   unless (save_record($temp, $id, $type)) {
     # Report failure:
-    display_warning("Unable to write the record with ID $id.");
+    display_warning("Unable to write the $type with ID $id.");
 
     # Return failure:
     return 0
@@ -587,7 +599,7 @@ sub edit_record {
   return 1;
 }
 
-# Add given string to the log file
+# Add the event to the log:
 sub add_to_log {
   my $text = shift || 'Something miraculous has just happened!';
 
@@ -597,7 +609,7 @@ sub add_to_log {
   # Open the log file for appending:
   open(LOG, ">>$file") or return 0;
 
-  # Write to the log file:
+  # Write the event to the file:
   print LOG localtime(time) . " - $text\n";
 
   # Close the file:
@@ -607,10 +619,10 @@ sub add_to_log {
   return 1;
 }
 
-# Set up the options parser:
+# Set up the option parser:
 Getopt::Long::Configure('no_auto_abbrev', 'no_ignore_case', 'bundling');
 
-# Process command-line options:
+# Process command line options:
 GetOptions(
   'help|h'         => sub { display_help();    exit 0; },
   'version|v'      => sub { display_version(); exit 0; },
@@ -621,12 +633,14 @@ GetOptions(
   'quiet|q'        => sub { $verbose = 0;      },
   'verbose|V'      => sub { $verbose = 1;      },
   'blogdir|b=s'    => sub { $blogdir = $_[1];  },
+  'editor|E=s'     => sub { $editor  = $_[1];  },
 );
 
 # Check superfluous options:
 exit_with_error("Wrong number of options.", 22) if (scalar(@ARGV) != 1);
 
-# Check the repository is present (however naive this method is):
+# Check whether the repository is present, no matter how naive this method
+# actually is:
 exit_with_error("Not a BlazeBlogger repository! Try `blaze-init' first.",1)
   unless (-d catdir($blogdir, '.blaze'));
 
@@ -644,7 +658,7 @@ else {
   $process = 0;
 }
 
-# Edit given record:
+# Edit the record:
 edit_record($ARGV[0], $type)
   or exit_with_error("Cannot edit the $type in the repository.", 13);
 
@@ -662,97 +676,105 @@ __END__
 
 =head1 NAME
 
-blaze-edit - edit a blog post or a page in the BlazeBlogger repository
+blaze-edit - edits a blog post or a page in the BlazeBlogger repository
 
 =head1 SYNOPSIS
 
-B<blaze-edit> [B<-fpqCPV>] [B<-b> I<directory>] I<id>
+B<blaze-edit> [B<-fpqCPV>] [B<-b> I<directory>] [B<-E> I<editor>] I<id>
 
-B<blaze-edit> B<-h> | B<-v>
+B<blaze-edit> B<-h>|B<-v>
 
 =head1 DESCRIPTION
 
-B<blaze-edit> enables you to edit a blog post or a page in your favourite
-text editor.
+B<blaze-edit> opens an existing blog post or a page with the specified
+I<id> in an external text editor. Note that there are several special forms
+and placeholders that can be used in the text, and that will be replaced
+with a proper data when the blog is generated.
 
-Note that inside your posts and pages, you can use several special
-placeholders to be replaced by appropriate data later, when the static
-content is being generated; the case is not significant, and supported
-placeholders are as follows:
+=head2 Special Forms
+
+=over
+
+=item B<< <!-- break --> >>
+
+A mark to delimit a blog post synopsis.
+
+=back
+
+=head2 Placeholders
 
 =over
 
 =item B<%root%>
 
-Relative path to the root directory of the blog; to be used inside links.
+A relative path to the root directory of the blog.
 
 =item B<%home%>
 
-Relative path to the website home (index) page; to be used inside links.
+A relative path to the index page of the blog.
 
 =item B<%page[>I<id>B<]%>
 
-Relative path to the page with given I<id>; to be used inside links.
+A relative path to a page with the supplied I<id>.
 
-=item B<%post[>I<id>B<]%>
+=item B<%post[>I<id>I<]%>
 
-Relative path to the post with given I<id>; to be used inside links.
+A relative path to a blog post with the supplied I<id>.
 
 =item B<%tag[>I<name>B<]%>
 
-Relative path to the tag with given I<name>; to be used inside links.
+A relative path to a tag with the supplied I<name>.
 
 =back
 
-You can also use a special form, B<< <!-- break --> >>, to mark the end of
-a part to be displayed on index page.
-
 =head1 OPTIONS
 
 =over
 
-=item B<-b>, B<--blogdir> I<directory>
+=item B<-b> I<directory>, B<--blogdir> I<directory>
 
-Specify the I<directory> where the BlazeBlogger repository is placed. The
-default option is the current working directory.
+Allows you to specify a I<directory> in which the BlazeBlogger repository
+is placed. The default option is a current working directory.
+
+=item B<-E> I<editor>, B<--editor> I<editor>
+
+Allows you to specify an external text I<editor>. When supplied, this
+option overrides the relevant configuration option.
 
 =item B<-p>, B<--page>
 
-Edit page instead of blog post.
+Tells B<blaze-edit> to edit a page or pages.
 
 =item B<-P>, B<--post>
 
-Edit blog post; this is the default option.
+Tells B<blaze-edit> to edit a blog post or blog posts. This is the default
+option.
 
 =item B<-f>, B<--force>
 
-Force creating a new, empty raw file when it does not already exist,
-although the C<core.processor> is enabled in the configuration; just be
-warned that this will rewrite whatever content is in the existing target
-file.
+Tells B<blaze-edit> to create an empty source file in case it does not
+already exist. If the B<core.processor> option is enabled, this file is
+used as the input to be processed by the selected application.
 
 =item B<-C>, B<--no-processor>
 
-Disable the use of external processor; just be warned that you will be
-editing the target (i.e. potentially previously processed) file instead of
-the raw source. Unless the C<core.processor> is enabled in the
-configuration, this is the default behaviour.
+Disables processing a blog post or page with an external application.
 
 =item B<-q>, B<--quiet>
 
-Avoid displaying messages that are not necessary.
+Disables displaying of unnecessary messages.
 
 =item B<-V>, B<--verbose>
 
-Display all messages. This is the default option.
+Enables displaying of all messages. This is the default option.
 
 =item B<-h>, B<--help>
 
-Display usage information and exit.
+Displays usage information and exits.
 
 =item B<-v>, B<--version>
 
-Display version information and exit.
+Displays version information and exits.
 
 =back
 
@@ -762,49 +784,38 @@ Display version information and exit.
 
 =item B<EDITOR>
 
-Unless the BlazeBlogger specific option I<core.editor> is set, blaze-edit
-tries to use system wide settings to decide which editor to run. If neither
-of these options are supplied, the B<vi> is used instead as a considerably
-reasonable choice.
+Unless the B<core.editor> option is set, BlazeBlogger tries to use
+system-wide settings to decide which editor to use.
 
 =back
 
-=head1 FILES
+=head1 EXAMPLE USAGE
 
-=over
+Edit a blog post in an external text editor:
 
-=item I<.blaze/config>
+  ~]$ blaze-edit 10
 
-BlazeBlogger configuration file.
+Edit a page in an external text editor:
 
-=back
+  ~]$ blaze-edit -p 4
+
+Edit a page in B<nano>:
+
+  ~]$ blaze-edit -p 2 -E nano
 
 =head1 SEE ALSO
 
-B<blaze-config>(1), B<perl>(1).
+B<blaze-config>(1), B<blaze-add>(1), B<blaze-list>(1)
 
 =head1 BUGS
 
-To report bug or even send patch, either add new issue to the project
-bugtracker at <http://code.google.com/p/blazeblogger/issues/>, or visit
-the discussion group at <http://groups.google.com/group/blazeblogger/>. You
-can also contact the author directly via e-mail.
-
-=head1 AUTHOR
-
-Written by Jaromir Hradilek <jhradilek@gmail.com>.
-
-Permission is granted to copy, distribute and/or modify this document under
-the terms of the GNU Free Documentation License, Version 1.3 or any later
-version published by the Free Software Foundation; with no Invariant
-Sections, no Front-Cover Texts, and no Back-Cover Texts.
-
-A copy of the license is included as a file called FDL in the main
-directory of the BlazeBlogger source package.
+To report a bug or to send a patch, please, add a new issue to the bug
+tracker at <http://code.google.com/p/blazeblogger/issues/>, or visit the
+discussion group at <http://groups.google.com/group/blazeblogger/>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2008, 2009 Jaromir Hradilek
+Copyright (C) 2008-2011 Jaromir Hradilek
 
 This program is free software; see the source for copying conditions. It is
 distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
