@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
-# blaze-init, create or recover a BlazeBlogger repository
-# Copyright (C) 2008, 2009 Jaromir Hradilek
+# blaze-init - creates or recovers a BlazeBlogger repository
+# Copyright (C) 2008-2011 Jaromir Hradilek
 
 # This program is  free software:  you can redistribute it and/or modify it
 # under  the terms  of the  GNU General Public License  as published by the
@@ -24,7 +24,7 @@ use Getopt::Long;
 
 # General script information:
 use constant NAME    => basename($0, '.pl');        # Script name.
-use constant VERSION => '1.0.0';                    # Script version.
+use constant VERSION => '1.2.0';                    # Script version.
 
 # General script settings:
 our $blogdir = '.';                                 # Repository location.
@@ -36,20 +36,26 @@ $SIG{__WARN__} = sub {
   print STDERR NAME . ": " . (shift);
 };
 
-# Display given message and terminate the script:
+# Display an error message, and terminate the script:
 sub exit_with_error {
-  my $message      = shift || 'An unspecified error has occurred.';
+  my $message      = shift || 'An error has occurred.';
   my $return_value = shift || 1;
 
+  # Display the error message:
   print STDERR NAME . ": $message\n";
+
+  # Terminate the script:
   exit $return_value;
 }
 
-# Display given warning message:
+# Display a warning message:
 sub display_warning {
-  my $message = shift || 'An unspecified warning was requested.';
+  my $message = shift || 'A warning was requested.';
 
+  # Display the warning message:
   print STDERR "$message\n";
+
+  # Return success:
   return 1;
 }
 
@@ -57,16 +63,17 @@ sub display_warning {
 sub display_help {
   my $NAME = NAME;
 
-  # Print the message to the STDOUT:
+  # Display the usage:
   print << "END_HELP";
-Usage: $NAME [-fqV] [-b directory]
-       $NAME -h | -v
+Usage: $NAME [-fqV] [-b DIRECTORY]
+       $NAME -h|-v
 
-  -b, --blogdir directory     specify the directory where the BlazeBlogger
+  -b, --blogdir DIRECTORY     specify a directory in which the BlazeBlogger
                               repository is to be placed
-  -f, --force                 force rewrite of already existing files
-  -q, --quiet                 avoid displaying unnecessary messages
-  -V, --verbose               display all messages including the list of
+  -f, --force                 revert existing configuration, theme, and
+                              language files to their initial state
+  -q, --quiet                 do not display unnecessary messages
+  -V, --verbose               display all messages, including a list of
                               created files
   -h, --help                  display this help and exit
   -v, --version               display version information and exit
@@ -80,11 +87,11 @@ END_HELP
 sub display_version {
   my ($NAME, $VERSION) = (NAME, VERSION);
 
-  # Print the message to the STDOUT:
+  # Display the version:
   print << "END_VERSION";
 $NAME $VERSION
 
-Copyright (C) 2008, 2009 Jaromir Hradilek
+Copyright (C) 2008-2011 Jaromir Hradilek
 This program is free software; see the source for copying conditions. It is
 distributed in the hope  that it will be useful,  but WITHOUT ANY WARRANTY;
 without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PAR-
@@ -100,97 +107,118 @@ sub create_conf {
   # Prepare the configuration file name:
   my $file = catfile($blogdir, '.blaze', 'config');
 
-  # Skip existing file unless forced:
+  # Unless explicitly requested, do not overwrite the existing file:
   return 1 if (-e $file && !$force);
 
   # Open the file for writing:
   open(FILE, ">$file") or return 0;
 
-  # Write given string to the file:
+  # Write the default configuration to the file:
   print FILE << 'END_CONFIG';
 ## This is the default BlazeBlogger configuration file. The recommended way
-## to set up your blog is to leave this file intact and use blaze-config(1)
-## instead.  Nevertheless, if you prefer to configure the settings by hand,
-## simply replace the value next to the equal sign.
+## to set up your blog is to leave  this file intact,  and use blaze-config
+## instead.  However, if you prefer to configure BlazeBlogger by hand, read
+## the instructions below,  and replace the value on the right of the equal
+## sign.
 
-## The following are the blog related settings, having the direct influence
-## on the way the whole thing looks. The options are as follows:
+## General blog settings. Available options are:
 ##
-##   title    - The blog title.
-##   subtitle - The blog subtitle, supposedly a brief, single-line descrip-
-##              tion of what should the occasional visitor  expect to find.
-##   theme    - The blog theme;  the value should point to an existing file
-##              in the .blaze/theme directory.
-##   style    - The blog style; the value should point to an existing file,
-##              either  in  .blaze/style,  or in the  destination directory
-##              where the static content is to be placed.
-##   lang     - The blog language;  the value  should point to an  existing
-##              file in the .blaze/lang directory.
-##   posts    - Number of posts to be listed on a single page;  the default
-##              value is 10.
-##   url      - The blog base url; required for RSS feed only.
+##   title         A title of your blog.
+##   subtitle      A subtitle of your blog.
+##   description   A brief description of your blog.
+##   keywords      A comma-separated list of keywords.
+##   theme         A theme for your blog. It must point to an existing file
+##                 in the .blaze/theme/ directory.
+##   style         A style sheet for your blog.  It must point to  an exis-
+##                 ting file in the .blaze/style/ directory.
+##   lang          A translation of your blog. It must point to an existing
+##                 file in the .blaze/lang/ directory.
+##   posts         A number of blog posts to be listed on a single page.
 ##
 [blog]
-title=My Blog
-subtitle=yet another blog
+title=Blog Title
+subtitle=blog subtitle
+description=blog description
+keywords=blog keywords
 theme=default.html
 style=default.css
-lang=en_GB
+lang=en_US
 posts=10
-url=
 
-## The following are the colour settings, affecting the way various outputs
-## look. The options are as follows:
+## Color settings. Available options are:
 ##
-##   list - Whether to use coloured posts/pages listing;  the value  has to
-##          be either true, or false.
-##   log  - Whether to use coloured repository log listing;  the value  has
-##          to be either true, or false.
+##   list          A boolean  to enable (true) or disable (false) colors in
+##                 the blaze-list output.
+##   log           A boolean  to enable (true) or disable (false) colors in
+##                 the blaze-log output.
 ##
 [color]
 list=false
 log=false
 
-## The following are the core settings,  affecting the way the BlazeBlogger
-## works. The options are as follows:
+## Advanced BlazeBlogger settings. Available options are:
 ##
-##   encoding  - Records  encoding in the form  recognised by the  W3C HTML
-##               4.01 standard (e.g. the default UTF-8).
-##   extension - File extension for the generated pages.
-##   editor    - An external text editor to be used for editing purposes.
-##   processor - An optional external application to be used to process the
-##               entries;  use %in% and %out% in place of input and  output
-##               files, for example: markdown --html4tags %in% > %out%
+##   doctype       A document type.  It can be  either  html  for HTML,  or
+##                 xhtml for the XHTML standard.
+##   extension     A file extension.
+##   encoding      A character encoding. It has to be in a form that is re-
+##                 cognized by W3C standards.
+##   editor        An external  text  editor.  When  supplied, this  option
+##                 overrides the system-wide settings.
+##   processor     An external application  to be used to process newly ad-
+##                 ded or edited blog posts and pages. You must supply %in%
+##                 and %out% in place of an input and output file name res-
+##                 pectively.
 ##
 [core]
-encoding=UTF-8
+doctype=html
 extension=html
+encoding=UTF-8
 editor=
 processor=
 
-## The following are the post related settings, making it possible to alter
-## the look of a single post even further. The options are as follows:
+## RSS feed settings. Available options are:
 ##
-##  author - Location of the author; available  options are top, bottom, or
-##           none.
-##  date   - Location of the date of publishing; available options are top,
-##           bottom, or none.
-##  tags   - Location of tags;  available options are top, bottom, or none.
+##  baseurl        A URL of your blog, for example "http://example.com/".
+##  posts          A number of blog posts to be listed in the feed.
+##  fullposts      A boolean to enable (true)  or disable (false) inclusion
+##                 of the whole content of a blog post in the feed.
+##
+[feed]
+baseurl=
+posts=10
+fullposts=false
+
+## Advanced post settings. Available options are:
+##
+##  author         A location of a blog post author name.  It can either be
+##                 placed above the post (top),  below it (bottom),  or no-
+##                 where on the page (none).
+##  date           A location  of a date  of publishing.  It can  either be
+##                 placed above the post (top),  below it (bottom),  or no-
+##                 where on the page (none).
+##  tags           A location of post tags. They can either be placed above
+##                 the post (top),  below it (bottom),  or  nowhere  on the
+##                 page (none).
 ##
 [post]
 author=top
 date=top
 tags=top
 
-## The following are the user related settings. The options are as follows:
+## User settings. Available options are:
 ##
-##   user  - User's name  to be used as a default posts' author  and in the
-##           copyright notice.
-##   email - User's e-mail.
+##   name          Your full name to be used in the copyright notice,  and
+##                 as the default post author.
+##   nickname      Your nickname  to be used  as the  default  post author.
+##                 When supplied, this option overrides the  above setting.
+##   email         Your email address.
 ##
 [user]
 name=admin
+nickname=
 email=admin@localhost
+
 END_CONFIG
 
   # Close the file:
@@ -208,23 +236,24 @@ sub create_theme {
   # Prepare the theme file name:
   my $file = catfile($blogdir, '.blaze', 'theme', 'default.html');
 
-  # Skip existing file unless forced:
+  # Unless explicitly requested, do not overwrite the existing file:
   return 1 if (-e $file && !$force);
 
   # Open the file for writing:
   open(FILE, ">$file") or return 0;
 
-  # Write given string to the file:
+  # Write the default theme to the file:
   print FILE << 'END_THEME';
-<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
-                      "http://www.w3.org/TR/html4/strict.dtd">
-<html>
+<!-- START-DOCUMENT -->
 <head>
   <!-- content-type -->
   <!-- generator -->
+  <!-- copyright -->
   <!-- date -->
+  <!-- description -->
+  <!-- keywords -->
   <!-- stylesheet -->
-  <!-- rss -->
+  <!-- feed -->
   <title><!-- page-title --></title>
 </head>
 
@@ -233,13 +262,13 @@ sub create_theme {
 <div id="wrapper">
   <div id="shadow">
     <div id="heading">
-      <h1><a href="%home%"><!-- title --></a></h1>
+      <h1><a href="%home%" rel="index"><!-- title --></a></h1>
       <!-- subtitle -->
     </div>
 
     <div id="menu">
       <ul>
-<li><a href="%home%">Home</a></li>
+<li><a href="%home%" rel="index">Home</a></li>
 <!-- pages -->
       </ul>
     </div>
@@ -273,7 +302,7 @@ sub create_theme {
 </div>
 
 </body>
-</html>
+<!-- END-DOCUMENT -->
 END_THEME
 
   # Close the file:
@@ -286,21 +315,21 @@ END_THEME
   return 1;
 }
 
-# Create the default style file:
+# Create the default style sheet:
 sub create_style {
-  # Prepare the style file name:
+  # Prepare the style sheet file name:
   my $file = catfile($blogdir, '.blaze', 'style', 'default.css');
 
-  # Skip existing file unless forced:
+  # Unless explicitly requested, do not overwrite the existing file:
   return 1 if (-e $file && !$force);
 
   # Open the file for writing:
   open(FILE, ">$file") or return 0;
 
-  # Write given string to the file:
+  # Write the default style style sheet to the file:
   print FILE << 'END_STYLE';
-/* default.css - the default BlazeBlogger theme
- * Copyright (C) 2009 Jaromir Hradilek
+/* default.css, the default theme for BlazeBlogger
+ * Copyright (C) 2009, 2010 Jaromir Hradilek
  *
  * This program is free software:  you can redistribute it and/or modify it
  * under  the terms of the  GNU General Public License  as published by the
@@ -527,18 +556,18 @@ END_STYLE
   return 1;
 }
 
-# Create the default language file:
+# Create the default localization file:
 sub create_lang {
-  # Prepare the language file name:
-  my $file = catfile($blogdir, '.blaze', 'lang', 'en_GB');
+  # Prepare the localization file name:
+  my $file = catfile($blogdir, '.blaze', 'lang', 'en_US');
 
-  # Skip existing file unless forced:
+  # Unless explicitly requested, do not overwrite the existing file:
   return 1 if (-e $file && !$force);
 
   # Open the file for writing:
   open(FILE, ">$file") or return 0;
 
-  # Write given string to the file:
+  # Write the default localization to the file:
   print FILE << 'END_LANG';
 [lang]
 archive=Archive for
@@ -574,7 +603,7 @@ END_LANG
   return 1;
 }
 
-# Add given string to the log file:
+# Add the event to the log:
 sub add_to_log {
   my $text = shift || 'Something miraculous has just happened!';
 
@@ -584,7 +613,7 @@ sub add_to_log {
   # Open the log file for appending:
   open(LOG, ">>$file") or return 0;
 
-  # Write to the log file:
+  # Write the event to the file:
   print LOG localtime(time) . " - $text\n";
 
   # Close the file:
@@ -594,10 +623,10 @@ sub add_to_log {
   return 1;
 }
 
-# Set up the options parser:
+# Set up the option parser:
 Getopt::Long::Configure('no_auto_abbrev', 'no_ignore_case', 'bundling');
 
-# Process command-line options:
+# Process command line options:
 GetOptions(
   'help|h'        => sub { display_help();    exit 0; },
   'version|v'     => sub { display_version(); exit 0; },
@@ -616,16 +645,18 @@ my $action = (-d catdir($blogdir, '.blaze')) ? 'Recovered' : 'Created';
 # Create the directory tree:
 eval {
   mkpath(
-    catdir($blogdir, '.blaze', 'lang'),
-    catdir($blogdir, '.blaze', 'theme'),
-    catdir($blogdir, '.blaze', 'style'),
-    catdir($blogdir, '.blaze', 'pages', 'head'),
-    catdir($blogdir, '.blaze', 'pages', 'body'),
-    catdir($blogdir, '.blaze', 'pages', 'raw'),
-    catdir($blogdir, '.blaze', 'posts', 'head'),
-    catdir($blogdir, '.blaze', 'posts', 'body'),
-    catdir($blogdir, '.blaze', 'posts', 'raw'),
-    { verbose => 0 }
+    [
+      catdir($blogdir, '.blaze', 'lang'),
+      catdir($blogdir, '.blaze', 'theme'),
+      catdir($blogdir, '.blaze', 'style'),
+      catdir($blogdir, '.blaze', 'pages', 'head'),
+      catdir($blogdir, '.blaze', 'pages', 'body'),
+      catdir($blogdir, '.blaze', 'pages', 'raw'),
+      catdir($blogdir, '.blaze', 'posts', 'head'),
+      catdir($blogdir, '.blaze', 'posts', 'body'),
+      catdir($blogdir, '.blaze', 'posts', 'raw'),
+    ],
+    0 # Do not be verbose.
   );
 };
 
@@ -634,21 +665,21 @@ exit_with_error("Creating directory tree: $@", 13) if $@;
 
 # Create the default configuration file:
 create_conf()
-  or display_warning("Unable to create the configuration file.");
+  or display_warning("Unable to create the default configuration file.");
 
-# Create the default theme file:
+# Create the default theme:
 create_theme()
-  or display_warning("Unable to create the default theme file.");
+  or display_warning("Unable to create the default theme.");
 
-# Create the default style file:
+# Create the default style sheet:
 create_style()
-  or display_warning("Unable to create the default style file.");
+  or display_warning("Unable to create the default style sheet.");
 
-# Create the default language file:
+# Create the default localization:
 create_lang()
-  or display_warning("Unable to create the default language file.");
+  or display_warning("Unable to create the default localization.");
 
-# Write to / create the log file:
+# Create the default log file:
 add_to_log("$action a BlazeBlogger repository.")
   or display_warning("Unable to log the event.");
 
@@ -663,79 +694,92 @@ __END__
 
 =head1 NAME
 
-blaze-init - create or recover a BlazeBlogger repository
+blaze-init - creates or recovers a BlazeBlogger repository
 
 =head1 SYNOPSIS
 
 B<blaze-init> [B<-fqV>] [B<-b> I<directory>]
 
-B<blaze-init> B<-h> | B<-v>
+B<blaze-init> B<-h>|B<-v>
 
 =head1 DESCRIPTION
 
-B<blaze-init>'s job is either to create a fresh new BlazeBlogger
-repository, or to recover an existing one, optionally changing the
-configuration and template files back to their original state while leaving
-the user data (i.e. both pages and blog posts) untouched.
+B<blaze-init> either creates a fresh new BlazeBlogger repository, or
+recovers an existing one in case it is corrupted. Optionally, it can also
+revert a configuration and default templates to their original state,
+leaving all user data (that is, both blog posts and pages) intact.
 
 =head1 OPTIONS
 
 =over
 
-=item B<-b>, B<--blogdir> I<directory>
+=item B<-b> I<directory>, B<--blogdir> I<directory>
 
-Specify the I<directory> where the BlazeBlogger repository is to be placed.
-The default option is the current working directory.
+Allows you to specify a I<directory> in which the BlazeBlogger repository
+is to be blaced. The default option is a current working directory.
 
 =item B<-f>, B<--force>
 
-Force rewrite of already existing configuration, style, theme and language
-files.
+Reverts existing configuration, theme, and language files to their initial
+state. By default, these files are kept intact.
 
 =item B<-q>, B<--quiet>
 
-Avoid displaying messages that are not necessary.
+Disables displaying of unnecessary messages.
 
 =item B<-V>, B<--verbose>
 
-Display all messages including the list of created files.
+Enables displaying of all messages, including a list of created files.
 
 =item B<-h>, B<--help>
 
-Display usage information and exit.
+Displays usage information and exits.
 
 =item B<-v>, B<--version>
 
-Display version information and exit.
+Displays version information and exits.
 
 =back
 
+=head1 EXAMPLE USAGE
+
+Create a new blog in a current directory:
+
+  ~]$ blaze-init
+  Created a BlazeBlogger repository in .blaze.
+
+Create a new blog in ~/public_html:
+
+  ~]$ blaze-init -b ~/public_html
+  Created a BlazeBlogger repository in /home/joe/public_html/.blaze.
+
+Revert a configuration file and default templates to their initial state:
+
+  ~]$ blaze-init -f
+  Recovered a BlazeBlogger repository in .blaze.
+
+Or if you want to see what files have been reverted:
+
+  ~]$ blaze-init -fV
+  Created .blaze/config
+  Created .blaze/theme/default.html
+  Created .blaze/style/default.css
+  Created .blaze/lang/en_US
+  Recovered a BlazeBlogger repository in .blaze.
+
 =head1 SEE ALSO
 
-B<blaze-config>(1), B<perl>(1).
+B<blaze-config>(1), B<blaze-add>(1)
 
 =head1 BUGS
 
-To report bug or even send patch, either add new issue to the project
-bugtracker at <http://code.google.com/p/blazeblogger/issues/>, or visit
-the discussion group at <http://groups.google.com/group/blazeblogger/>. You
-can also contact the author directly via e-mail.
-
-=head1 AUTHOR
-
-Written by Jaromir Hradilek <jhradilek@gmail.com>.
-
-Permission is granted to copy, distribute and/or modify this document under
-the terms of the GNU Free Documentation License, Version 1.3 or any later
-version published by the Free Software Foundation; with no Invariant
-Sections, no Front-Cover Texts, and no Back-Cover Texts.
-
-A copy of the license is included as a file called FDL in the main
-directory of the BlazeBlogger source package.
+To report a bug or to send a patch, please, add a new issue to the bug
+tracker at <http://code.google.com/p/blazeblogger/issues/>, or visit the
+discussion group at <http://groups.google.com/group/blazeblogger/>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2008, 2009 Jaromir Hradilek
+Copyright (C) 2008-2011 Jaromir Hradilek
 
 This program is free software; see the source for copying conditions. It is
 distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
