@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
-# blaze-list, browse the content of the BlazeBlogger repository
-# Copyright (C) 2009 Jaromir Hradilek
+# blaze-list - lists blog posts or pages in the BlazeBlogger repository
+# Copyright (C) 2009-2011 Jaromir Hradilek
 
 # This program is  free software:  you can redistribute it and/or modify it
 # under  the terms  of the  GNU General Public License  as published by the
@@ -25,20 +25,20 @@ use Text::Wrap;
 
 # General script information:
 use constant NAME    => basename($0, '.pl');        # Script name.
-use constant VERSION => '1.0.0';                    # Script version.
+use constant VERSION => '1.2.0';                    # Script version.
 
 # General script settings:
 our $blogdir    = '.';                              # Repository location.
 our $verbose    = 1;                                # Verbosity level.
 our $compact    = 0;                                # Use compact listing?
-our $coloured   = undef;                            # Use coloured listing?
+our $coloured   = undef;                            # Use colors?
 our $reverse    = 0;                                # Use reverse order?
 our $number     = 0;                                # Listed records limit.
 
 # Global variables:
 our $conf       = {};                               # Configuration.
 
-# Command-line options:
+# Command line options:
 my  $type       = 'post';                           # Type: post or page.
 my  $id         = '';                               # ID search pattern.
 my  $title      = '';                               # Title search pattern.
@@ -53,20 +53,26 @@ $SIG{__WARN__}  = sub {
   print STDERR NAME . ": " . (shift);
 };
 
-# Display given message and terminate the script:
+# Display an error message, and terminate the script:
 sub exit_with_error {
-  my $message      = shift || 'An unspecified error has occurred.';
+  my $message      = shift || 'An error has occurred.';
   my $return_value = shift || 1;
 
+  # Display the error message:
   print STDERR NAME . ": $message\n";
+
+  # Terminate the script:
   exit $return_value;
 }
 
-# Display given warning message:
+# Display a warning message:
 sub display_warning {
-  my $message = shift || 'An unspecified warning was requested.';
+  my $message = shift || 'A warning was requested.';
 
+  # Display the warning message:
   print STDERR "$message\n";
+
+  # Return success:
   return 1;
 }
 
@@ -74,32 +80,33 @@ sub display_warning {
 sub display_help {
   my $NAME = NAME;
 
-  # Print the message to the STDOUT:
+  # Display the usage:
   print << "END_HELP";
-Usage: $NAME [-cpqrsCPSV] [-b directory] [-I id] [-a author]
-                  [-t title] [-T tag] [-d day] [-m month] [-y year]
-                  [-n number]
-       $NAME -h | -v
+Usage: $NAME [-cpqrsCPSV] [-b DIRECTORY] [-I ID] [-a AUTHOR]
+                  [-t TITLE] [-T TAG] [-d DAY] [-m MONTH] [-y YEAR]
+                  [-n NUMBER]
+       $NAME -h|-v
 
-  -b, --blogdir directory     specify the directory where the BlazeBlogger
+  -b, --blogdir DIRECTORY     specify a directory in which the BlazeBlogger
                               repository is placed
-  -I, --id id                 display record with specified ID
-  -a, --author author         list records by specified author
-  -t, --title title           list records with matching title
-  -T, --tag tag               list records with matching tag
-  -d, --day day               list records from the day in the DD form
-  -m, --month month           list records from the month in the MM form
-  -y, --year year             list records from the year in the YYYY form
-  -n, --number number         list selected number of records only
-  -p, --pages                 list pages instead of blog posts
-  -P, --posts                 list blog posts; the default option
-  -S, --stats                 show repository statistics instead of posts
-  -s, --short                 display each record on a single line
-  -r, --reverse               display records in reverse order
-  -c, --color                 enable coloured output
-  -C, --no-color              disable coloured output
-  -q, --quiet                 avoid displaying unnecessary messages
-  -V, --verbose               display all messages; the default option
+  -I, --id ID                 display a single blog post or a page
+  -a, --author AUTHOR         list blog posts or pages by selected author
+  -t, --title TITLE           list blog posts or pages with matching title
+  -T, --tag TAG               list blog posts or pages with matching tag
+  -d, --day DAY               list blog posts or pages from selected day
+  -m, --month MONTH           list blog posts or pages from selected month
+  -y, --year YEAR             list blog posts or pages from selected year
+  -n, --number NUMBER         specify a number of blog posts or pages to
+                              be listed
+  -p, --pages                 list pages
+  -P, --posts                 list blog posts
+  -S, --stats                 display repository statistics
+  -s, --short                 display blog posts or pages on a single line
+  -r, --reverse               display blog posts or pages in reverse order
+  -c, --color                 enable colored output
+  -C, --no-color              disable colored output
+  -q, --quiet                 do not display unnecessary messages
+  -V, --verbose               display all messages
   -h, --help                  display this help and exit
   -v, --version               display version information and exit
 END_HELP
@@ -112,11 +119,11 @@ END_HELP
 sub display_version {
   my ($NAME, $VERSION) = (NAME, VERSION);
 
-  # Print the message to the STDOUT:
+  # Display the version:
   print << "END_VERSION";
 $NAME $VERSION
 
-Copyright (C) 2009 Jaromir Hradilek
+Copyright (C) 2009-2011 Jaromir Hradilek
 This program is free software; see the source for copying conditions. It is
 distributed in the hope  that it will be useful,  but WITHOUT ANY WARRANTY;
 without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PAR-
@@ -127,7 +134,7 @@ END_VERSION
   return 1;
 }
 
-# Translate given date to YYYY-MM-DD string:
+# Translate a date to the YYYY-MM-DD form:
 sub date_to_string {
   my @date = localtime(shift);
   return sprintf("%d-%02d-%02d", ($date[5] + 1900), ++$date[4], $date[3]);
@@ -146,13 +153,13 @@ sub read_ini {
 
   # Process each line:
   while (my $line = <INI>) {
-    # Parse line:
+    # Parse the line:
     if ($line =~ /^\s*\[([^\]]+)\]\s*$/) {
       # Change the section:
       $section = $1;
     }
     elsif ($line =~ /^\s*(\S+)\s*=\s*(\S.*)$/) {
-      # Add option to the hash:
+      # Add the option to the hash:
       $hash->{$section}->{$1} = $2;
     }
   }
@@ -164,7 +171,7 @@ sub read_ini {
   return $hash;
 }
 
-# Read the configuration file:
+# Read the content of the configuration file:
 sub read_conf {
   # Prepare the file name:
   my $file = catfile($blogdir, '.blaze', 'config');
@@ -176,14 +183,14 @@ sub read_conf {
   }
   else {
     # Report failure:
-    display_warning("Unable to read configuration.");
+    display_warning("Unable to read the configuration.");
 
-    # Return empty configuration:
+    # Return an empty configuration:
     return {};
   }
 }
 
-# Compose a post/page record:
+# Compose a blog post or a page record:
 sub make_record {
   my $type = shift || die 'Missing argument';
   my $id   = shift || die 'Missing argument';
@@ -208,7 +215,7 @@ sub make_record {
     # Assign the default value:
     $author = $conf->{user}->{name} || 'admin';
 
-    # Report missing author:
+    # Report the missing author:
     display_warning("Missing author in the $type with ID $id. " .
                     "Using `$author' instead.");
   }
@@ -220,7 +227,7 @@ sub make_record {
       # Use current date instead:
       $date = date_to_string(time);
 
-      # Report invalid date:
+      # Report the invalid date:
       display_warning("Invalid date in the $type with ID $id. " .
                       "Using `$date' instead.");
     }
@@ -229,7 +236,7 @@ sub make_record {
     # Use current date instead:
     $date = date_to_string(time);
 
-    # Report missing date:
+    # Report the missing date:
     display_warning("Missing date in the $type with ID $id. " .
                     "Using `$date' instead.");
   }
@@ -270,14 +277,16 @@ sub make_record {
 sub compare_records {
   # Check whether to use reverse order:
   unless ($reverse) {
-    return "$b->{date}:$b->{id}" cmp "$a->{date}:$a->{id}";
+    return sprintf("%s:%08d", $b->{date}, $b->{id}) cmp
+           sprintf("%s:%08d", $a->{date}, $a->{id});
   }
   else {
-    return "$a->{date}:$a->{id}" cmp "$b->{date}:$b->{id}";
+    return sprintf("%s:%08d", $a->{date}, $a->{id}) cmp
+           sprintf("%s:%08d", $b->{date}, $b->{id});
   }
 }
 
-# Return the list of posts/pages header records:
+# Return a list of blog post or page header records:
 sub collect_headers {
   my $type    = shift || 'post';
 
@@ -318,20 +327,20 @@ sub collect_headers {
   return sort compare_records @records;
 }
 
-# Display given record:
+# Display a record:
 sub display_record {
   my $record = shift || die 'Missing argument';
 
   # Check whether to use compact listing:
   unless ($compact) {
-    # Check whether to use colours:
+    # Check whether colors are enabled:
     unless ($coloured) {
-      # Display the plain record header:
+      # Display plain record header:
       print "ID: $record->{id} | $record->{date} | " .
             "$record->{author}\n\n";
     }
     else {
-      # Display the coloured record header:
+      # Display colored record header:
       print colored ("ID: $record->{id} | $record->{date} | " .
                      "$record->{author}", 'yellow');
       print "\n\n";
@@ -353,7 +362,7 @@ sub display_record {
 }
 
 
-# Display the list of matching records:
+# Display a list of matching records:
 sub display_records {
   my $type    = shift || 'post';
   my $id      = shift || '.*';
@@ -367,7 +376,7 @@ sub display_records {
   # Initialize required variables:
   my $count   = 0;
 
-  # Collect the pages/posts headers:
+  # Collect blog post or page headers:
   my @headers = collect_headers($type);
 
   # Process each header:
@@ -387,10 +396,10 @@ sub display_records {
 
     # Check whether the limited number of displayed records is requested:
     if ($number > 0) {
-      # Increase displayed records counter:
+      # Increase the displayed records counter:
       $count++;
 
-      # End loop when counter reaches the limit:
+      # End loop when the counter reaches the limit:
       last if $count == $number;
     }
   }
@@ -399,7 +408,7 @@ sub display_records {
   return 1;
 }
 
-# Display repository statistics:
+# Display the repository statistics:
 sub display_statistics {
   # Collect the necessary metadata:
   my @pages = collect_headers('page');
@@ -413,7 +422,7 @@ sub display_statistics {
 
   # Check whether to use compact listing:
   unless ($compact) {
-    # Display the full results:
+    # Display full results:
     print "Number of pages: $pages_count\n";
     print "Number of posts: $posts_count\n";
     print "Last post date:  $last_post\n"  if @posts;
@@ -431,16 +440,16 @@ sub display_statistics {
   return 1;
 }
 
-# Set up the options parser:
+# Set up the option parser:
 Getopt::Long::Configure('no_auto_abbrev', 'no_ignore_case', 'bundling');
 
-# Process command-line options:
+# Process command line options:
 GetOptions(
   'help|h'               => sub { display_help();    exit 0; },
   'version|v'            => sub { display_version(); exit 0; },
   'page|pages|p'         => sub { $type     = 'page';  },
   'post|posts|P'         => sub { $type     = 'post';  },
-  'stats|S'              => sub { $type     = 'stats'; },
+  'stat|stats|S'         => sub { $type     = 'stats'; },
   'number|n=i'           => sub { $number   = $_[1];   },
   'id|I=i'               => sub { $id       = $_[1];   },
   'author|a=s'           => sub { $author   = $_[1];   },
@@ -461,15 +470,16 @@ GetOptions(
 # Detect superfluous options:
 exit_with_error("Invalid option `$ARGV[0]'.", 22) if (scalar(@ARGV) != 0);
 
-# Check the repository is present (however naive this method is):
+# Check whether the repository is present, no matter how naive this method
+# actually is:
 exit_with_error("Not a BlazeBlogger repository! Try `blaze-init' first.",1)
   unless (-d catdir($blogdir, '.blaze'));
 
-# Read the configuration:
+# Read the configuration file:
 $conf = read_conf();
 
-# Unless specified on the command line, read the colour setup from the
-# configuration:
+# Unless specified on the command line, read the color setup from the
+# configuration file:
 unless (defined $coloured) {
   # Read required data from the configuration:
   my $temp  = $conf->{color}->{list} || 'false';
@@ -478,12 +488,13 @@ unless (defined $coloured) {
   $coloured = ($temp =~ /^(true|auto)\s*$/i) ? 1 : 0;
 }
 
-# Check whether to post/pages, or show statistics:
+# Check whether to list blog posts or pages, or display repository
+# statistics:
 unless ($type eq 'stats') {
   # Prepare the list of reserved characters:
   my $reserved  = '[\\\\\^\.\$\|\(\)\[\]\*\+\?\{\}]';
 
-  # Escape reserved characters:
+  # Escape all reserved characters:
   $id     =~ s/($reserved)/\\$1/g if $id;
   $author =~ s/($reserved)/\\$1/g if $author;
   $title  =~ s/($reserved)/\\$1/g if $title;
@@ -497,7 +508,7 @@ unless ($type eq 'stats') {
     or exit_with_error("Cannot read repository data.", 13);
 }
 else {
-  # Display repository statistics:
+  # Display the repository statistics:
   display_statistics()
     or exit_with_error("Cannot read repository data.", 13);
 }
@@ -509,7 +520,7 @@ __END__
 
 =head1 NAME
 
-blaze-list - browse the content of the BlazeBlogger repository
+blaze-list - lists blog posts or pages in the BlazeBlogger repository
 
 =head1 SYNOPSIS
 
@@ -517,131 +528,177 @@ B<blaze-list> [B<-cpqrsCPSV>] [B<-b> I<directory>] [B<-I> I<id>]
 [B<-a> I<author>] [B<-t> I<title>] [B<-T> I<tag>] [B<-d> I<day>]
 [B<-m> I<month>] [B<-y> I<year>] [B<-n> I<number>]
 
-B<blaze-list> B<-h> | B<-v>
+B<blaze-list> B<-h>|B<-v>
 
 =head1 DESCRIPTION
 
-B<blaze-list> displays the content of the BlazeBlogger repository. All
-items are listed by default, but desired subset can be easily selected via
-additional options.
+B<blaze-list> lists existing blog posts or pages in the BlazeBlogger
+repository. Additionally, it can also display basic repository statistics.
 
 =head1 OPTIONS
 
 =over
 
-=item B<-b>, B<--blogdir> I<directory>
+=item B<-b> I<directory>, B<--blogdir> I<directory>
 
-Specify the I<directory> where the BlazeBlogger repository is placed. The
-default option is the current working directory.
+Allows you to specify a I<directory> in which the BlazeBlogger repository
+is placed. The default option is a current working directory.
 
-=item B<-I>, B<--id> I<id>
+=item B<-I> I<id>, B<--id> I<id>
 
-Display the record with specified I<id> only.
+Allows you to display a single blog post or a page with the specified
+I<id>.
 
-=item B<-a>, B<--author> I<author>
+=item B<-a> I<author>, B<--author> I<author>
 
-List records by specified I<author> only.
+Allows you to list blog posts or pages by the selected I<author>.
 
-=item B<-t>, B<--title> I<title>
+=item B<-t> I<title>, B<--title> I<title>
 
-List records with matching I<title>.
+Allows you to list blog posts or pages with matching I<title>.
 
-=item B<-T>, B<--tag> I<tag>
+=item B<-T> I<tag>, B<--tag> I<tag>
 
-List records tagged as I<tag>.
+Allows you to list blog posts or pages with matching I<tag>.
 
-=item B<-d>, B<--day> I<day>
+=item B<-d> I<day>, B<--day> I<day>
 
-List records from the specified day where I<day> is in the DD format. Do
-not forget to specify the month and year as well, unless you, for example,
-want to list all records from the first day of every month.
+Allows you to list blog posts or pages from the specified I<day> of a
+month. The value has to be in the C<DD> form.
 
-=item B<-m>, B<--month> I<month>
+=item B<-m> I<month>, B<--month> I<month>
 
-List records from the specified month where I<month> is in the MM format.
-Do not forget to specify the year as well, unless you, for example, want to
-list all july records.
+Allows you to list blog posts or pages from the specified I<month>. The
+value has to be in the C<MM> form.
 
-=item B<-y>, B<--year> I<year>
+=item B<-y> I<year>, B<--year> I<year>
 
-List records from the specified year where I<year> is in the YYYY format.
+Allows you to list blog posts or pages from the specified I<year>. The
+value has to be in the C<YYYY> form.
 
-=item B<-n>, B<--number> I<number>
+=item B<-n> I<number>, B<--number> I<number>
 
-List selected I<number> of records only.
+Allows you to specify a I<number> of blog posts or pages to be listed.
 
-=item B<-p>, B<--pages>
+=item B<-p>, B<--page>
 
-List pages instead of blog posts.
+Tells B<blaze-list> to list pages.
 
-=item B<-P>, B<--posts>
+=item B<-P>, B<--post>
 
-List blog posts; this is the default option.
+Tells B<blaze-list> to list blog posts. This is the default option.
 
 =item B<-S>, B<--stats>
 
-Show repository statistics instead of blog posts.
+Tells B<blaze-list> to display statistics.
 
 =item B<-s>, B<--short>
 
-Display each record on a single line.
+Tells B<blaze-list> to display each blog post or page information on a
+single line.
 
 =item B<-r>, B<--reverse>
 
-Display records in reverse order.
+Tells B<blaze-list> to display blog posts or pages in reverse order.
 
-=item B<-c>, B<--color>, B<--colour>
+=item B<-c>, B<--color>
 
-Enable coloured output, no matter what is set in the configuration.
+Enables colored output. When supplied, this option overrides the relevant
+configuration option.
 
-=item B<-C>, B<--no-color>, B<--no-colour>
+=item B<-C>, B<--no-color>
 
-Disable coloured output, no matter what is set in the configuration.
+Disables colored output. When supplied, this option overrides the relevant
+configuration option.
 
 =item B<-q>, B<--quiet>
 
-Avoid displaying messages that are not necessary.
+Disables displaying of unnecessary messages.
 
 =item B<-V>, B<--verbose>
 
-Display all messages. This is the default option.
+Enables displaying of all messages. This is the default option.
 
 =item B<-h>, B<--help>
 
-Display usage information and exit.
+Displays usage information and exits.
 
 =item B<-v>, B<--version>
 
-Display version information and exit.
+Displays version information and exits.
 
 =back
 
+=head1 EXAMPLE USAGE
+
+List all blog post:
+
+  ~]$ blaze-list
+  ID: 11 | 2010-07-05 | Jaromir Hradilek
+
+      Title: Join #blazeblogger on IRC
+      Tags:  announcement
+
+  ID: 10 | 2009-12-16 | Jaromir Hradilek
+
+      Title: Debian and Fedora Packages
+      Tags:  announcement
+
+  etc.
+
+List all blog post in reverse order:
+
+  ~]$ blaze-list -r
+  ID: 1 | 2009-02-10 | Jaromir Hradilek
+
+      Title: BlazeBlogger 0.7.0
+      Tags:  release
+
+  ID: 2 | 2009-02-11 | Jaromir Hradilek
+
+      Title: BlazeBlogger 0.7.1
+      Tags:  release
+
+  etc.
+
+List all pages:
+
+  ~]$ blaze-list -p
+  ID: 5 | 2009-02-10 | Jaromir Hradilek
+
+      Title: Downloads
+
+  ID: 4 | 2009-02-10 | Jaromir Hradilek
+
+      Title: Themes
+
+  etc.
+
+List each blog post on a single line:
+
+  ~]$ blaze-list -s
+  ID: 11 | 2010-07-05 | Join #blazeblogger on IRC
+  ID: 10 | 2009-12-16 | Debian and Fedora Packages
+  etc.
+
+Display a short version of blog statistics:
+
+  ~]$ blaze-list -Ss
+  There is a total number of 11 blog posts and 5 pages in the repository.
+
 =head1 SEE ALSO
 
-B<perl>(1).
+B<blaze-config>(1), B<blaze-add>(1)
 
 =head1 BUGS
 
-To report bug or even send patch, either add new issue to the project
-bugtracker at <http://code.google.com/p/blazeblogger/issues/>, or visit
-the discussion group at <http://groups.google.com/group/blazeblogger/>. You
-can also contact the author directly via e-mail.
-
-=head1 AUTHOR
-
-Written by Jaromir Hradilek <jhradilek@gmail.com>.
-
-Permission is granted to copy, distribute and/or modify this document under
-the terms of the GNU Free Documentation License, Version 1.3 or any later
-version published by the Free Software Foundation; with no Invariant
-Sections, no Front-Cover Texts, and no Back-Cover Texts.
-
-A copy of the license is included as a file called FDL in the main
-directory of the BlazeBlogger source package.
+To report a bug or to send a patch, please, add a new issue to the bug
+tracker at <http://code.google.com/p/blazeblogger/issues/>, or visit the
+discussion group at <http://groups.google.com/group/blazeblogger/>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009 Jaromir Hradilek
+Copyright (C) 2009-2011 Jaromir Hradilek
 
 This program is free software; see the source for copying conditions. It is
 distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
